local moduleName = "player"

local L = AceLibrary('AceLocale-2.2'):new('SimpleUnitFrames_Player')

L:RegisterTranslations('enUS', function() return {

	player_desc = "Options for player frame",
	
	mhp = "Middle Heath Text",
	rhp = "Right Health Text",
	mmp = "Middle Mana Text",
	rmp = "Right Mana Text",
	mhp_desc = "Set middle health text to one of the styles",
	rhp_desc = "Set right health text to one of the styles",
	mmp_desc = "Set middle mana text to one of the styles",
	rmp_desc = "Set right health text to one of the styles",
	
} end)

local Player = SimpleUnitFrames:NewModule(moduleName, "AceEvent-2.0")

Player.core.defaults[moduleName] = {
	mhp = "currmaxhp",
	rhp = "percenthp",
	mmp = "currmaxmp",
	rmp = "percentmp",
}

Player.consoleOptions = {
	type = 'group',
	name = 'player',
	desc = L['player_desc'],
	args = {	
		mhp = {
			type = 'group',
			name = L['mhp'],
			desc = L['mhp_desc'],
			args = {}
		},
		rhp = {
			type = 'group',
			name = L['rhp'],
			desc = L['rhp_desc'],
			args = {}
		},
		mmp = {
			type = 'group',
			name = L['mmp'],
			desc = L['mmp_desc'],
			args = {}
		},
		rmp = {
			type = 'group',
			name = L['rmp'],
			desc = L['rmp_desc'],
			args = {}
		},
	}
}

function Player:OnInitialize()

	self:PopulateOptions(self.consoleOptions, self.db)
	
	self:RegisterEvent("UNIT_HEALTH")
	self:RegisterEvent("UNIT_MANA", "OnManaChange")
	self:RegisterEvent("UNIT_RAGE", "OnManaChange")
	self:RegisterEvent("UNIT_FOCUS", "OnManaChange")
	self:RegisterEvent("UNIT_ENERGY", "OnManaChange")
	self:RegisterEvent("UNIT_DISPLAYPOWER", "OnManaChange")
	
	self:UpdateHealth()
	self:UpdateMana()
	
	-- Disable the default player HP/MP text.
	hooksecurefunc(PlayerFrameHealthBar.TextString, "Show", self.Show)
	hooksecurefunc(PlayerFrameManaBar.TextString, "Show", self.Show)
	
end

-- The hook: Hide() on Show()!
function Player.Show(textString)
	textString:Hide()
end


function Player:UNIT_HEALTH(arg1)
	if arg1 == 'player' then
		self:UpdateHealth()
	end
end

function Player:OnManaChange(arg1)
	if arg1 == 'player' then
		self:UpdateMana()
	end
end


function Player:UpdateHealth()
	SUF_HealthMiddleText:SetText( self:GetValueText('player', self.db.mhp ) )
	SUF_HealthRightText:SetText( self:GetValueText('player', self.db.rhp ) )	
end

function Player:UpdateMana()
	SUF_ManaMiddleText:SetText( self:GetValueText('player', self.db.mmp ) )
	SUF_ManaRightText:SetText( self:GetValueText('player', self.db.rmp ) )	
end
